<?php
App::uses('EvCustomFieldsAppModel', 'EvCustomFields.Model');
/**
 * EvCustomFields.Field Model
 *
 */
class Field extends EvCustomFieldsAppModel {

	/**
	 * Display field
	 *
	 * @var string
	 */
	public $displayField = 'name';

	/**
	 * Validation rules
	 *
	 * @var array
	 */
	public $validate = array(
		'name' => array(
			'notEmpty' => array(
				'rule' => array('notBlank'),
				'message' => 'Your custom field must have a name',
				//'allowEmpty' => false,
				//'required' => false,
				//'last' => false, // Stop validation after this rule
				//'on' => 'create', // Limit validation to 'create' or 'update' operations
			),
			'uniqueName' => array(
				'rule' => array('checkItemUnique'),
				'message' => 'Your custom field name must be unique'
			)
		),
		'type' => array(
			'notEmpty' => array(
				'rule' => array('notBlank'),
				'message' => 'Your custom field must have a type',
				//'allowEmpty' => false,
				//'required' => false,
				//'last' => false, // Stop validation after this rule
				//'on' => 'create', // Limit validation to 'create' or 'update' operations
			),
		),
	);

	/**
	 * hasMany associations
	 *
	 * @var array
	 */
	public $hasMany = array(
		'FieldData' => array(
			'className' => 'EvCustomFields.FieldData',
			'dependent' => true,
			'cascade' => true
		)
	);

	/**
	 * get fields for validation of data
	 *
	 * @param 	array 	array of Field Ids to find get validation for
	 * @return 	array
	 */
	public function getValidation($fieldIds) {
		$fields = $this->find(
			'list',
			array(
				'fields' => array('id', 'validation'),
				'conditions' => array(
					'Field.id' => $fieldIds
				)
			)
		);

		$validation = array_map(
			function ($rules) {

				if (! empty($rules)) {
					return json_decode($rules, true);
				}

				return array();
			},
			$fields
		);

		return $validation;
	}

	/**
	 * check for unique custom field names
	 * need amend unique check to take into account model / model_id
	 *
	 */
	public function checkItemUnique($check) {
		$conditions = array(
			'Field.name' => $check['name'],
			'Field.model' => $this->data[$this->alias]['model'],
			'Field.model_id' => $this->data[$this->alias]['model_id']
		);

		if (! empty($this->data[$this->alias]['id'])) {
			$conditions['Field.id !='] = $this->data[$this->alias]['id'];
		}

		$count = $this->find(
			'count',
			array(
				'conditions' => $conditions,
				'callbacks' => false
			)
		);

		if ($count > 0) {
			return false;
		}

		return true;
	}

}
